=======
Credits
=======

Development Lead
----------------

* Vianney Taquet <vtaquet@quantmetry.com>
* Grégoire Martinon <gmartinon@quantmetry.com>

Contributors
------------

* Nicolas Brunel <nbrunel@quantmetry.com>
* Issam Ibnouhsein <iibnouhsein@quantmetry.com>
* François Deheeger <francois.deheeger@michelin.com>
* Rémi Adon <remi.adon@protonmail.com>

To be continued ...